============
Терминология
============

.. glossary::

    лексема
        Набор всех форм одного слова. Например, "ёж", "ежи" и "ежам"
        входят в одну лексему. [1]_

    лемма
    нормальная форма слова
        Каноническая форма слова (например, форма единственного числа,
        именительного падежа для существительных). [2]_

    граммема
        Значение какой-либо грамматической характеристики слова.
        Например, "множественное число" или "деепричастие".
        Множество всех граммем, характеризующих данное слово,
        образует :term:`тег`.

        См. также: :ref:`grammeme-docs`.

    тег
        Набор :term:`граммем <граммема>`, характеризующих данное слово.
        Например, для слова "ежам" тегом может быть
        ``'NOUN,anim,masc plur,datv'``.


    парадигма
    словоизменительная парадигма
        Образец для склонения или спряжения; правила, согласно которым
        можно получить все формы слов в :term:`лексеме <лексема>` для данного
        :term:`стема <стем>`.

        В pymorphy2 для каждого слова в словаре указано, по каким парадигмам
        это слово могло быть образовано; pymorphy2 также умеет предсказывать
        парадигму для слов, отсутствующих в словаре.

    стем
        Неизменяемая часть слова.


.. [1]

    Часто не делается различия между леммой и лексемой, или термин
    "лемма" употребляется в значении "набор форм слова". Но, похоже,
    данное выше определение лексемы все же более стандартное (см., например,
    см. `википедию`_ или `Foundations of Statistical Natural Language Processing`_),
    поэтому в pymorphy2 набор всех форм слова называется именно лексемой.

.. [2]

    В pymorphy1 и в XML-словаре из OpenCorpora слово "лемма"
    употребляется в значении "лексема". Чтобы не усугублять путаницу,
    в pymorphy2 вместо термина "лемма" употребляется термин
    "нормальная форма слова", а термин "лемма" не используется совсем.


.. _википедию: https://ru.wikipedia.org/wiki/%D0%9B%D0%B5%D0%BA%D1%81%D0%B5%D0%BC%D0%B0_(%D0%BB%D0%B8%D0%BD%D0%B3%D0%B2%D0%B8%D1%81%D1%82%D0%B8%D0%BA%D0%B0)
.. _Foundations of Statistical Natural Language Processing: https://nlp.stanford.edu/fsnlp/

